@@ -1,6 +1,9 @@
 #!/usr/bin/env bash
 # jenkins build helper script for libasn1c.  This is how we build on jenkins.osmocom.org
 
+set -e
+osmo-clean-workspace.sh
+
 set +x
 echo
 echo
@@ -10,7 +13,9 @@ echo
 set -x
 
 autoreconf --install --force
-./configure CFLAGS="-Werror" CPPFLAGS="-Werror"
+./configure --enable-werror
 $MAKE $PARALLEL_MAKE
 $MAKE distcheck \
   || cat-testlogs.sh
+
+osmo-clean-workspace.sh
